@@ -93,6 +93,7 @@ from .utils import sha3_256, int_to_bytes, ContextEngine, ContextStorage
 from .utils import to_camel_case, bytes_to_hex
 from .utils.bloom import BloomFilter
 from .utils.timer import Timer
+from .utils.test_env import is_under_testing
 
 if TYPE_CHECKING:
     from .iconscore.icon_score_event_log import EventLog
@@ -442,6 +443,9 @@ class IconServiceEngine(ContextContainer):
         block_result = []
         added_transactions = {}
 
+        if not is_under_testing():
+            IconScoreContext.engine.iiss.send_start_block(block.height, block.hash)
+
         self._before_transaction_process(context,
                                          is_block_editable,
                                          tx_requests,
@@ -456,10 +460,13 @@ class IconServiceEngine(ContextContainer):
             context.block_batch.update(context.tx_batch)
             context.tx_batch.clear()
         else:
+            one_tx_timer = Timer()
             tx_timer = Timer()
             tx_timer.start()
 
             for index, tx_request in enumerate(tx_requests):
+                one_tx_timer.start()
+
                 tx_hash: Optional[bytes] = tx_request["params"].get("txHash")
                 Logger.debug(_TAG, f"INVOKE tx: tx_hash={bytes_to_hex(tx_hash)} {tx_request}")
 
@@ -495,7 +502,15 @@ class IconServiceEngine(ContextContainer):
                 if context.is_revision_changed(Revision.FIX_BALANCE_BUG.value):
                     self._run_unstake_patcher(context)
 
-                Logger.debug(_TAG, f"INVOKE txResult: {tx_result}")
+                Logger.info(
+                    tag=_TAG,
+                    msg=f"TX_END: "
+                        f"BH={tx_result.block_height} "
+                        f"txIndex={tx_result.tx_index} "
+                        f"to={tx_result.to} "
+                        f"duration={one_tx_timer.duration}"
+                )
+                Logger.debug(tag=_TAG, msg=f"INVOKE txResult: {tx_result}")
 
         if self._check_end_block_height_of_calc(context):
             context.revision_changed_flag |= RevisionChangedFlag.IISS_CALC
