@@ -333,22 +333,25 @@ class QueryRequest(Request):
     """queryIScore
     """
 
-    def __init__(self, address: 'Address', tx_hash: Optional[bytes]):
+    def __init__(self, address: 'Address', block_height: int, block_hash: Optional[bytes], tx_hash: Optional[bytes]):
         super().__init__(MessageType.QUERY)
 
         self.address = address
+        self.block_height = block_height
+        self.block_hash = block_hash
         self.tx_hash = tx_hash
 
     def __str__(self) -> str:
         return (
-            f"{self.msg_type.name}"
-            f"({self.msg_id}, {self.address}, {bytes_to_hex(self.tx_hash)})"
+            f"{self.msg_type.name}, "
+            f"({self.msg_id}, {self.address}, {self.block_height}, {bytes_to_hex(self.block_hash)}, "
+            f"{bytes_to_hex(self.tx_hash)})"
         )
 
     def _to_list(self) -> tuple:
         return self.msg_type, \
                self.msg_id, \
-               (self.address.to_bytes_including_prefix(), self.tx_hash)
+               (self.address.to_bytes_including_prefix(), self.block_height, self.block_hash, self.tx_hash)
 
 
 class QueryResponse(Response):
